#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wuss
version:              2.0.1.7
visibility:           public
id:                   wuss-2.0.1.7-B1lNzWkVZLXKNZnmsDuoTg
key:                  wuss-2.0.1.7-B1lNzWkVZLXKNZnmsDuoTg
license:              MIT
maintainer:           Taylor Fausak
synopsis:             Secure WebSocket (WSS) clients
description:
    Wuss is a library that lets you easily create secure WebSocket clients over
    the WSS protocol. It is a small addition to
    <https://hackage.haskell.org/package/websockets the websockets package> and
    is adapted from existing solutions by
    <https://gist.github.com/jaspervdj/7198388 @jaspervdj>,
    <https://gist.github.com/mpickering/f1b7ba3190a4bb5884f3 @mpickering>, and
    <https://gist.github.com/elfenlaid/7b5c28065e67e4cf0767 @elfenlaid>.

category:             Network
abi:                  ec6c5fc1abd2d9eebad44008803149c8
exposed:              True
exposed-modules:      Wuss
import-dirs:          /usr/lib/ghc-9.6.6/site-local/wuss-2.0.1.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wuss-2.0.1.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wuss-2.0.1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wuss
hs-libraries:         HSwuss-2.0.1.7-B1lNzWkVZLXKNZnmsDuoTg
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    crypton-connection-0.4.5-4CyvLXsefWe2BxkRUg0ltk exceptions-0.10.7
    network-3.1.4.0-4Rsy3d52Nm21mbavP5v2o
    websockets-0.12.7.3-Kfmo7flFoDf1FHWYGXCLBs

haddock-interfaces:   /usr/share/doc/haskell-wuss/html/wuss.haddock
haddock-html:         /usr/share/doc/haskell-wuss/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

